@@ -32,13 +32,13 @@ from typing import Iterator, List
 
 from botocore.paginate import Paginator as Boto3Paginator
 
-from mypy_boto3_ram.literals import (
-    ResourceOwner,
-    ResourceShareAssociationStatus,
-    ResourceShareAssociationType,
-    ResourceShareStatus,
+from .literals import (
+    ResourceOwnerType,
+    ResourceShareAssociationStatusType,
+    ResourceShareAssociationTypeType,
+    ResourceShareStatusType,
 )
-from mypy_boto3_ram.type_defs import (
+from .type_defs import (
     GetResourcePoliciesResponseTypeDef,
     GetResourceShareAssociationsResponseTypeDef,
     GetResourceShareInvitationsResponseTypeDef,
@@ -61,113 +61,120 @@ __all__ = (
 
 class GetResourcePoliciesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Paginator.GetResourcePolicies)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourcepoliciespaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Paginator.GetResourcePolicies)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourcepoliciespaginator)
     """
 
     def paginate(
         self,
+        *,
         resourceArns: List[str],
         principal: str = None,
-        PaginationConfig: PaginatorConfigTypeDef = None,
+        PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[GetResourcePoliciesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Paginator.GetResourcePolicies.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Paginator.GetResourcePolicies.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourcepoliciespaginator)
         """
 
 
 class GetResourceShareAssociationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourceshareassociationspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourceshareassociationspaginator)
     """
 
     def paginate(
         self,
-        associationType: ResourceShareAssociationType,
+        *,
+        associationType: ResourceShareAssociationTypeType,
         resourceShareArns: List[str] = None,
         resourceArn: str = None,
         principal: str = None,
-        associationStatus: ResourceShareAssociationStatus = None,
-        PaginationConfig: PaginatorConfigTypeDef = None,
+        associationStatus: ResourceShareAssociationStatusType = None,
+        PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[GetResourceShareAssociationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourceshareassociationspaginator)
         """
 
 
 class GetResourceShareInvitationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourceshareinvitationspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourceshareinvitationspaginator)
     """
 
     def paginate(
         self,
+        *,
         resourceShareInvitationArns: List[str] = None,
         resourceShareArns: List[str] = None,
-        PaginationConfig: PaginatorConfigTypeDef = None,
+        PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[GetResourceShareInvitationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourceshareinvitationspaginator)
         """
 
 
 class GetResourceSharesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Paginator.GetResourceShares)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourcesharespaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Paginator.GetResourceShares)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourcesharespaginator)
     """
 
     def paginate(
         self,
-        resourceOwner: ResourceOwner,
+        *,
+        resourceOwner: ResourceOwnerType,
         resourceShareArns: List[str] = None,
-        resourceShareStatus: ResourceShareStatus = None,
+        resourceShareStatus: ResourceShareStatusType = None,
         name: str = None,
         tagFilters: List[TagFilterTypeDef] = None,
-        PaginationConfig: PaginatorConfigTypeDef = None,
+        permissionArn: str = None,
+        PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[GetResourceSharesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Paginator.GetResourceShares.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Paginator.GetResourceShares.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourcesharespaginator)
         """
 
 
 class ListPrincipalsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Paginator.ListPrincipals)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#listprincipalspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Paginator.ListPrincipals)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#listprincipalspaginator)
     """
 
     def paginate(
         self,
-        resourceOwner: ResourceOwner,
+        *,
+        resourceOwner: ResourceOwnerType,
         resourceArn: str = None,
         principals: List[str] = None,
         resourceType: str = None,
         resourceShareArns: List[str] = None,
-        PaginationConfig: PaginatorConfigTypeDef = None,
+        PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListPrincipalsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Paginator.ListPrincipals.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Paginator.ListPrincipals.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#listprincipalspaginator)
         """
 
 
 class ListResourcesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Paginator.ListResources)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#listresourcespaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Paginator.ListResources)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#listresourcespaginator)
     """
 
     def paginate(
         self,
-        resourceOwner: ResourceOwner,
+        *,
+        resourceOwner: ResourceOwnerType,
         principal: str = None,
         resourceType: str = None,
         resourceArns: List[str] = None,
         resourceShareArns: List[str] = None,
-        PaginationConfig: PaginatorConfigTypeDef = None,
+        PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListResourcesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/ram.html#RAM.Paginator.ListResources.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ram.html#RAM.Paginator.ListResources.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#listresourcespaginator)
         """
